@@ -411,13 +411,22 @@ HARDWARE = [
         auto_on=True,
         dimmable_effects=False,
     ),
+    LEDENETHardware(
+        model="AK001-ZJ2131",  # seen on 0x33 larger mini ones
+        chip=LEDENETChip.S82GESNC,  # couldn't get the device appart
+        remote_rf=False,
+        remote_24g=False,
+        remote_24g_controls=False,
+        auto_on=True,
+        dimmable_effects=False,
+    ),
     LEDENETHardware(
         model="AK001-ZJ2134",  # seen in smart plugs only?
         chip=LEDENETChip.S82GESNC,  # couldn't get the device appart
         remote_rf=False,
         remote_24g=False,
         remote_24g_controls=False,
-        auto_on=False,
+        auto_on=True,
         dimmable_effects=False,
     ),
     LEDENETHardware(
@@ -650,7 +659,7 @@ MODELS = [
     LEDENETModel(
         model_num=0x04,
         # AK001-ZJ100 == v3.09, v3.15 (Illume)
-        # AK001-ZJ200 == v5.20
+        # AK001-ZJ200 == v4.17 (Mini), v5.20
         # AK001-ZJ2104 == v6.20 (Dals)
         # There are a limited set of these devices that are the mini version but most are UFOs
         models=[
@@ -676,12 +685,14 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x06,
+        # "AK001-ZJ2134" == v1.02
         # "AK001-ZJ2104" == v1.11 has RF remote support
         # "AK001-ZJ2145" == v2.03, v2.06, v2.09 has IR remote support but not always pinned out
         # "AK001-ZJ2147" == v3.31 has 2.4ghz remote support
         models=[
             "AK001-ZJ100",
             "AK001-ZJ200",
+            "AK001-ZJ2134",
             "AK001-ZJ2104",
             "AK001-ZJ2145",
             "AK001-ZJ2147",
@@ -789,9 +800,10 @@ MODELS = [
         device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
+        # 'AK001-ZJ2147' is v1.25
         model_num=0x1A,
         models=["AK001-ZJ2147"],
-        description="Christmas Light",
+        description="String Lights",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_ADDRESSABLE_CHRISTMAS)],
         mode_to_color_mode={},
@@ -910,10 +922,10 @@ MODELS = [
     LEDENETModel(
         model_num=0x21,
         # 'AK001-ZJ200' is v1 but with new firmware it will change to v2
-        # 'AK001-ZJ2104' is v2
-        # 'AK001-ZJ2104' likely supports turning on by effect/levels set
-        models=["AK001-ZJ200", "AK001-ZJ2101", "AK001-ZJ2104"],
-        description="Bulb Dimmable",
+        # 'AK001-ZJ210' is v2.45
+        # 'AK001-ZJ2104' is v2 - likely supports turning on by effect/levels set
+        models=["AK001-ZJ200", "AK001-ZJ210", "AK001-ZJ2101", "AK001-ZJ2104"],
+        description="Bulb Dimmable",  # Also seen on mini inline dimmers
         always_writes_white_and_colors=True,  # Verified required with AK001-ZJ200 bulb
         protocols=[
             MinVersionProtocol(2, PROTOCOL_LEDENET_8BYTE_AUTO_ON),
@@ -945,6 +957,7 @@ MODELS = [
         # 'AK001-ZJ2104' == v7.07 - Seen on usb fairy lights - supports turning on by effect/levels set
         # 'AK001-ZJ2134' == v8.02 - seen on the water proof controllers for outdoor garden light
         # 'AK001-ZJ2101' == v8.61, 8.62 (44 key) - no dimmable effects confirmed, confirmed auto on
+        # 'AK001-ZJ2131' == v8.38 larger mini controller - no dimmable effects confirmed, confirmed auto on
         # "AK001-ZJ2145" == v9.25, v9.27, 9.30, 9.33 # w/IR
         # "AK001-ZJ2146" == v10.48 # 2.4ghz support, some have IR
         # "AK001-ZJ2148" == v10.63 # 2.4ghz support, confirmed to be able to change 2.4G remote settings
@@ -953,6 +966,7 @@ MODELS = [
             "AK001-ZJ210",
             "AK001-ZJ2104",
             "AK001-ZJ2101",
+            "AK001-ZJ2131",
             "AK001-ZJ2134",
             "AK001-ZJ2145",
             "AK001-ZJ2146",
@@ -973,6 +987,7 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x35,
+        # 'AK001-ZJ200' is v5.17, 5.33
         # 'AK001-ZJ2101' is v7.63
         # 'AK001-ZJ2104' is v7.07
         # 'AK001-ZJ2145' is v8.47, v8.56 - seen on 7w bulbs
@@ -980,6 +995,7 @@ MODELS = [
         # 'AK001-ZJ2147' is v9.7 (with RF remote control support)
         # 'AK001-ZJ21410' is v9.91 seen on the Bunpeon smart floor light ASIN:B09MN65324
         models=[
+            "AK001-ZJ200",
             "AK001-ZJ2101",
             "AK001-ZJ2104",
             "AK001-ZJ2145",
@@ -1018,10 +1034,11 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x44,
+        # v5 - HF-LPB100-ZJ200 - Schultze imports 7w bulb
         # v8 - AK001-ZJ200 aka old flux
         # v9.34 - AK001-ZJ210
         # v10.49 - AK001-ZJ2101
-        models=["AK001-ZJ200", "AK001-ZJ210", "AK001-ZJ2101"],
+        models=["HF-LPB100-ZJ200", "AK001-ZJ200", "AK001-ZJ210", "AK001-ZJ2101"],
         description="Bulb RGBW",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[
@@ -1155,8 +1172,9 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x97,  # 0x97
+        # AK001-ZJ210 = v2.28
         # AK001-ZJ2146 = v3.11, 3.12 (has BLE)
-        models=["AK001-ZJ2134", "AK001-ZJ2146"],
+        models=["AK001-ZJ210", "AK001-ZJ2134", "AK001-ZJ2146"],
         description="Socket",  # 1 channel
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_SOCKET)],
